local mod = ...


-- Building Asset Processor -------------------------------------------------------------------------------------
mod:registerAssetProcessor("models/Dragon1.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })



-- Building -------------------------------------------------------------------------------------
mod:registerAsset({
	DataType = "BUILDING", 
	Id = "BUILDING_DRAGON",
	Name = "BUILDING_DRAGON_NAME",
	Description = "BUILDING_DRAGON_DESC",
	BuildingType = "MODS",
	AssetCoreBuildingPart = "BUILDING_PART_MONUMENT_POLE",
    AssetMiniatureBuildingPart = "BUILDING_PART_DRAGON_DRAGON1",
	BuildingPartSetList = {
		{
			Name = "BUILDING_PART_SETLIST_DRAGON1_NAME",
			BuildingPartList = {
				"BUILDING_PART_DRAGON_TRIBUTE1",
				"BUILDING_PART_DRAGON_TRIBUTE2",
				"BUILDING_PART_DRAGON_TRIBUTE3",
				"BUILDING_PART_DRAGON_TRIBUTE4",
			},
        },
		-- {
		-- 	Name = "BUILDING_PART_SETLIST_DRAGON2_NAME",
		-- 	BuildingPartList = {
		-- 		"BUILDING_PART_DRAGON_BALLISTA1",
		-- 	},
        -- },
		{
			Name = "BUILDING_PART_SETLIST_DRAGON3_NAME",
			BuildingPartList = {
				"BUILDING_PART_DRAGON_DRAGON1",
				-- "BUILDING_PART_DRAGON_DRAGON2",
				-- "BUILDING_PART_DRAGON_DRAGON3",
			},
        },
    },
    VillagerRequired = { Status = "NEWCOMER", Quantity = 50 },
})



-- Register Tribute -------------------------------------------------------------------------------------

-- Asset
mod:registerAssetId("models/Dragon1.fbx/Prefab/Tribute.Part", "PREFAB_DRAGON_TRIBUTE")

-- Component
mod:registerPrefabComponent("PREFAB_DRAGON_TRIBUTE", { DataType = "COMP_DRAGON_TRIBUTE" } )

-- Building Part
local function registerTribute(index, resource, quantity)

    mod:registerAsset({
        DataType = "BUILDING_PART",
        Id = "BUILDING_PART_DRAGON_TRIBUTE" .. index,
        Name = "BUILDING_PART_DRAGON_TRIBUTE" .. index .. "_NAME",
        ConstructorData = {
            DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
            CoreObjectPrefab = "PREFAB_DRAGON_TRIBUTE",
        },
        Cost = {
            BuildRightTaxes = {
                { Resource = resource, Quantity = quantity }
            },
        },
    })

end

registerTribute(1, "GOLD_COINS", 100)
registerTribute(2, "GOLD_BARS", 20)
registerTribute(3, "GEMS", 4)
registerTribute(4, "JEWELRY", 2)



-- Register Dragon -------------------------------------------------------------------------------------
local function registerDragon(index)

    -- Asset
    mod:registerAssetId("models/Dragon" .. index .. ".fbx/Prefab/Dragon.Part." .. index, "PREFAB_DRAGON_DRAGON" .. index)
    mod:registerAssetId("models/Dragon" .. index .. ".fbx/Prefab/Dragon.Part." .. index .. "/Emitter", "PREFAB_DRAGON_DRAGON" .. index .. "_EMITTER")

    -- Particle Emitter
    mod:registerPrefabComponent("PREFAB_DRAGON_DRAGON" .. index .. "_EMITTER", {
        DataType = "COMP_PARTICLE_EMITTER",
        ParticleSystem = "PARTICLE_SYSTEM_DRAGON_FIRE",
        IsPlaying = true,
        IsEmitting = false,
    })

    -- Building Part
    mod:registerAsset({
        DataType = "BUILDING_PART",
        Id = "BUILDING_PART_DRAGON_DRAGON" .. index,
        Name = "BUILDING_PART_DRAGON_DRAGON" .. index .. "_NAME",
        ConstructorData = {
            DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
            CoreObjectPrefab = "PREFAB_DRAGON_DRAGON" .. index,
            MiniatureConfig = {
                ClipUnderGround = true,
                GroupHeight = 0.0,
                CameraPosition = { 0, 0, -20 },
                OrientationOffset = 0.0,
                CameraPitchOffset = -15.0
            },
        },
    })

end

registerDragon(1)
-- registerDragon(2)
-- registerDragon(3)

